// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 2nd July 2005
//
// Purpose:       Demo shows how to use the window-system,
//                with the object-window.
//
// -----------------------------------------------------------------------------
#include <hel.h>
#include "lookups.h"


// -----------------------------------------------------------------------------
// Defines
// -----------------------------------------------------------------------------
#define NUM_SPRITES 40


// -----------------------------------------------------------------------------
// Global Variables
// -----------------------------------------------------------------------------
u8  g_NewFrame=TRUE;
u8  g_Sprites[NUM_SPRITES] ATTR_MEM_IN_EWRAM;
u32 g_FramesTotal=0;

// -----------------------------------------------------------------------------
// External Data
// -----------------------------------------------------------------------------
extern const unsigned short balls_Palette[256];
extern const unsigned char balls_Bitmap[2048];
extern const unsigned short girlbg_Palette[256];
extern const unsigned char girlbg_Bitmap[38400];

// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void);



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    u8 i;
    
    ham_Init();
    ham_SetBgMode(4);

    // Load Backgroundpicture and immediatly
    // flip the backbuffer to display its content.
    ham_LoadBitmap((void*)&girlbg_Bitmap);
    ham_FlipBGBuffer();

   // Create an object (sprite)
   g_Sprites[0] = ham_CreateObj((void *)&balls_Bitmap[0],  // A pointer to the tile data for this object
                              0,                       // obj_shape
                              2,                       // obj_size
      /* See here ------> */  OBJ_MODE_OBJWINDOW,      // obj_mode
                              1,                       // col_mode
                              0,                       // pal_no
                              0,                       // mosaic
                              0,                       // hflip
                              0,                       // vflip
                              0,                       // dbl_size
                              0,                       // prio
                              30,                      // x position of sprite on screen
                              30);                     // y position of sprite on screen
                              
    // Clone object
    for(i=1; i<NUM_SPRITES; i++)
    {
        // Cloning a sprite means having another ham_obj entry that you can play
        // with that uses a copy of the data set up for the sprite specified in objno.
    	 g_Sprites[i] = ham_CloneObj(g_Sprites[0], 1, 1);
    }

    // Setup an OBJ-Window
    // Since only transparent obj-pixels form the window,
    // we do not need to specify any region
    hel_WinInit(2, 0, 0, 0, 0, WIN_NONE, WIN_ALL);

    // Load Background Palette
    hel_PalBgLoad256((void *)&girlbg_Palette);
    
    // Inits the Palette for the Sprite
    hel_PalObjLoad256((void *)&balls_Palette);
    
    // Start VBL Interrupt
    ham_StartIntHandler(INT_TYPE_VBL, (void *)&VBLInterruptHandler);

                       
    for(;;)
    {
        if(g_NewFrame)
        {
            for(i=0;i<NUM_SPRITES;i++)
            {
                // Update X and Y Sprite Coordinates
                hel_ObjSetXY(g_Sprites[i], wobble_x[(g_FramesTotal+(i*2))%120], wobble_y[(g_FramesTotal+(i*3))%300]);
            }
            
            g_NewFrame=FALSE;
        }
    }
}


// -----------------------------------------------------------------------------
// VBL Interrupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler()
{
   ham_CopyObjToOAM();
   
   g_NewFrame=TRUE;
   g_FramesTotal++;
}


