// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 2nd July 2005
//
// Purpose:       Demo shows how to use the window-system.
//
// -----------------------------------------------------------------------------
#include <hel.h>


// -----------------------------------------------------------------------------
// Global Variables
// -----------------------------------------------------------------------------
u8 g_NewFrame=TRUE;


// -----------------------------------------------------------------------------
// External Data
// -----------------------------------------------------------------------------
extern const unsigned short girlbg_Palette[256];
extern const unsigned char girlbg_Bitmap[38400];


// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void);



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    ham_SetBgMode(4);

    // Load Backgroundpicture and immediatly
    // flip the backbuffer to display its content.
    ham_LoadBitmap((void*)&girlbg_Bitmap);
    ham_FlipBGBuffer();

    // Init a Window
    hel_WinInit(0,          // WinNo
                30,         // Left
                30,         // Top
                60,         // Right
                60,         // Bottom
                WIN_ALL,    // InsideFlags
                WIN_NONE);  // OutsideFlags

    // Load Background Palette
    hel_PalBgLoad256((void *)&girlbg_Palette);
    
    // Start VBL Interrupt
    ham_StartIntHandler(INT_TYPE_VBL, (void *)&VBLInterruptHandler);
    
    
    for(;;)
    {
        if(g_NewFrame)
        {
            #define WINDOW_WIDTH  115
            #define WINDOW_HEIGHT 75
            
            static TPoint32 WinPos={30,30};
            static s32 DeltaX=1;
            static s32 DeltaY=1;
            
            if(((WinPos.X+=DeltaX) <= 0) || ((WinPos.X+=DeltaX) >= 240-WINDOW_WIDTH)) { WinPos.X-=DeltaX;  DeltaX*=-1; }
            if(((WinPos.Y+=DeltaY) <= 0) || ((WinPos.Y+=DeltaY) >= 160-WINDOW_HEIGHT)){ WinPos.Y-=DeltaY;  DeltaY*=-1; }
            
            hel_WinSetRegion(0, WinPos.X, WinPos.Y, WinPos.X+WINDOW_WIDTH, WinPos.Y+WINDOW_HEIGHT);
            
            g_NewFrame=FALSE;
        }
    }
}


// -----------------------------------------------------------------------------
// VBL Interrupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler()
{
   ham_CopyObjToOAM();

   g_NewFrame=TRUE;
}

